@@ -33,11 +33,13 @@ from .film import Film
 from .shot import Shot
 from .task import Task
 from .users import User
+from .site import WorkingSite
 from .file import (
     TrackedFile,
     TrackedFolder,
     Revision,
     TrackedFolderRevision,
+    PublishFileAction,
 )
 from .runners import (
     DefaultRunners,
@@ -119,12 +121,16 @@ class Project(flow.Object):
             return TrackedFile
         elif slot_name == 'libreflow.baseflow.file.TrackedFolder':
             return TrackedFolder
+        elif slot_name == 'libreflow.baseflow.file.PublishFileAction':
+            return PublishFileAction
         elif slot_name == 'libreflow.baseflow.file.Revision':
             return Revision
         elif slot_name == 'libreflow.baseflow.file.TrackedFolderRevision':
             return TrackedFolderRevision
         elif slot_name == 'libreflow.baseflow.users.User':
             return User
+        elif slot_name == 'libreflow.baseflow.site.WorkingSite':
+            return WorkingSite
     
     def get_contextual_view(self, context_name):
         if context_name == 'settings':
