@@ -16,6 +16,12 @@ class Palas(EditFileRunner):
     @classmethod
     def supported_extensions(cls):
         return ['.plas']
+    
+    def show_terminal(self):
+        return True
+    
+    def keep_terminal(self):
+        return False
 
 
 class Houdoo(EditFileRunner):
